package bioinformatica.programmazione.esami.giugno.secondaparte;

public class VerificaCrescenza {

	public static void main(String[] args) {
		int[] vett1 = { 1, 2, 4, 6, 5, 12, 3, 4, 6, 20 };
		int[] vett2 = { 1, 2, 6, 6, 8, 12, 13, 24, 36, 36 };

		System.out.println("Primo vettore crescente: "
				+ vettoreCrescente(vett1, 0));
		System.out.println("Primo vettore crescente: "
				+ vettoreCrescente(vett1, 6));
		System.out.println("Secondo vettore crescente: "
				+ vettoreCrescente(vett2, 0));
	}

	/**
	 * Dato il vettore <code>vett</code>, verifica se gli elementi che compaiono
	 * dalla dalla posizione <code>pos</code> (compresa) fino alla fine
	 * dell'array sono in ordine crescente,
	 * 
	 * I valori significativi per <code>pos</code> vanno da 0 all'ultima
	 * posizine del vettore (<code>vett.length - 1</code>). <br>
	 * CASO BASE: se <code>pos</code> == vett.length - 1</code> dobbiamo
	 * verificare la crescenza su un singolo elemento: restituiamo
	 * <code>true</code>. <br>
	 * PASSO INDUTTIVO: se <code>pos < vett.length - 1</code> restituiamo
	 * <code>true</code> se <code>vett[pos] <= vett[pos + 1]</code> ed e'
	 * crescente la porzione di vett che va da <code>pos + 1</code> fino alla
	 * fine; altrimenti restituiamo <code>false</code>.
	 * 
	 * @param vett
	 *            vettore in cui verificare la crescenza
	 * @param pos
	 *            posizione da cui verificare la crescenza
	 * @return <code>true</code> se <code>pos</code> e' nel range degli inidici
	 *         di <code>vett</code> e i valori da <code>pos</code> fino alla
	 *         fine del vettore sono in ordine crescente, <code>false</code>
	 *         altrimenti.
	 */
	private static boolean vettoreCrescente(int[] vett, int pos) {
		// verifichiamo che pos possa essere l'indice di un array.
		if (pos < 0 || pos >= vett.length)
			return false;

		// PRECONDIZIONE: 0 <= pos < vett.length
		if (pos == vett.length - 1)
			return true;
		return vett[pos] <= vett[pos + 1] && vettoreCrescente(vett, pos + 1);
	}

}
