package bioinformatica.programmazione.esami.giugno.terzaparte;

/**
 * Rappresenta insiemi modificabili di stringhe. Sono possibili l'aggiunta e la
 * cancellazione di elementi.
 * 
 * @author mace
 * @version 1.0
 * 
 */

public interface ModifiableSet extends Set {

	/**
	 * Aggiunge un elemento all'insieme. L'inserimento ha successo solo se
	 * l'elemento non e' gia' presente nell'insieme.
	 * 
	 * @param element
	 *            elemento da aggiungere
	 * @return <code>true</code> se <code>element</code> e' effettivamente
	 *         aggiunto; <code>false</code> altrimenti.
	 */
	boolean add(String element);

	/**
	 * Rimuove un elemento dall'insieme. La rimozione ha successo solo se
	 * l'elemento e' effettivamente rimosso dall'insieme.
	 * 
	 * @param element
	 *            elemento da rimuovere.
	 * @return <code>true</code> se <code>element</code> e' effettivamente
	 *         rimosso; <code>false</code> altrimenti.
	 */
	boolean remove(String element);

	/**
	 * Aggiunge tutti gli elementi indicati all'insieme. L'inserimento ha
	 * successo solo se almeno un elemento e' effettivamente aggiunto
	 * all'insieme.
	 * 
	 * @param set
	 *            gli elementi da aggiungere.
	 * @return <code>true</code> se almeno un elemento viene effettivamente
	 *         aggiunto; <code>false</code> altrimenti.
	 */
	boolean addAll(Set set);

	/**
	 * Rimuove tutti gli elementi indicati dall'insieme. La rimozione ha
	 * successo solo se almeno un elemento e' effettivamente rimosso
	 * dall'insieme.
	 * 
	 * @param set
	 *            gli elementi da rimuovere.
	 * @return <code>true</code> se almeno un elemento viene effettivamente
	 *         rimosso; <code>false</code> altrimenti.
	 */
	boolean removeAll(Set set);
}
